import type { Gitlab } from "../types"
import GitlabBaseService from "./base"

class Badge extends GitlabBaseService {
  /**
   * 为特定项目检索 GitLab 徽章。
   * @returns {Promise<Gitlab.Badge[]>} 一个承诺，解析为 GitLab 徽章的数组。
   */
  async getList(): Promise<Gitlab.Badge[]> {
    const URL = `/projects/${this.project_id}/badges`
    return this.errorWarp<Gitlab.Badge[]>(() => this.get(URL), [])
  }

  /**
   * 设置 GitLab 徽章。
   * @param {BadgeSetParams} badge - 徽章参数。
   * @returns {Promise<Gitlab.Badge | null>} 一个承诺，解析为更新后的徽章。
   */
  async set(badge: Gitlab.BadgeSetParams): Promise<Gitlab.Badge | null> {
    const URL = `/projects/${badge.id}/badges/${badge.badge_id}`
    return this.errorWarp<Gitlab.Badge>(() => this.put(URL, badge), null)
  }

  /**
   * 添加 GitLab 徽章。
   * @param {BadgeSetParams} badge - 徽章参数。
   * @returns {Promise<Gitlab.Badge | null>} 一个承诺，解析为添加的徽章。
   */
  async add(badge: Gitlab.BadgeSetParams): Promise<Gitlab.Badge | null> {
    const URL = `/projects/${badge.id}/badges`
    return this.errorWarp<Gitlab.Badge>(() => this.post(URL, badge), null)
  }
}

export default Badge
